@@ -1,5 +1,3 @@
-context("require_namespaces")
-
 test_that("require_namespaces", {
   expect_equal(require_namespaces("mlr3misc"), "mlr3misc")
   expect_equal(require_namespaces("checkmate"), "checkmate")
@@ -10,4 +8,7 @@ test_that("require_namespaces", {
 
   expect_equal(tryCatch(require_namespaces("this_is_not_a_package999"),
     packageNotFoundError = function(e) e$packages), "this_is_not_a_package999")
+
+  expect_true(require_namespaces("mlr3misc", quietly = TRUE))
+  expect_false(require_namespaces("this_is_not_a_package999", quietly = TRUE))
 })
